@@ -1,4 +1,4 @@
-# Copyright 2010-2020 The pygit2 contributors
+# Copyright 2010-2021 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -614,6 +614,8 @@ class BaseRepository(_Repository):
 
         options = ffi.new('git_blame_options *')
         C.git_blame_init_options(options, C.GIT_BLAME_OPTIONS_VERSION)
+        if flags:
+            options.flags = flags
         if min_match_characters:
             options.min_match_characters = min_match_characters
         if newest_commit:
@@ -1465,12 +1467,14 @@ class References:
 class Repository(BaseRepository):
     def __init__(self, path=None, flags=0):
         """
-        The Repository constructor will commonly be called with one argument, the path of the repository to open.
+        The Repository constructor will commonly be called with one argument,
+        the path of the repository to open.
 
-        Alternatively, constructing a repository with no arguments will create a repository with no backends. You can
-        use this path to create repositories with custom backends. Note that most operations on the repository are
-        considered invalid and may lead to undefined behavior if attempted before providing an odb and refdb via set_odb
-        and set_refdb.
+        Alternatively, constructing a repository with no arguments will create
+        a repository with no backends. You can use this path to create
+        repositories with custom backends. Note that most operations on the
+        repository are considered invalid and may lead to undefined behavior if
+        attempted before providing an odb and refdb via set_odb and set_refdb.
 
         Parameters:
 
